gchecky.gxml.Decimal

Package gchecky :: Module gxml :: Class Decimal |
[hide private]
[frames] | no frames]

# Class Decimal

source code

    object --+
             |
         Field --+
                 |
                Decimal

Instance Methods | [hide private]
data2str(self, data) Override this method in subclasses | source code
str2data(self, text) Override this method in subclasses | source code
Inherited from `Field`: `__init__`, `__repr__`, `create_node_for_path`, `get_any_node_for_path`, `get_initial_value`, `get_nodes_for_path`, `get_one_node_for_path`, `load`, `save`, `validate` Inherited from `Field` (private): `_traits` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__str__`

Class Methods | [hide private]
Inherited from `Field`: `deconstruct_path`, `reconstruct_path`

Class Variables | [hide private]
| default = `0` the default value for the field

Instance Variables | [hide private]
Inherited from `Field`: `empty`, `path`, `required`, `save_node_and_xml`, `values`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### data2str(self, data) | source code
Override this method in subclasses Overrides: Field.data2str (inherited documentation)

### str2data(self, text) | source code
Override this method in subclasses Overrides: Field.str2data (inherited documentation)